@@ -276,7 +276,7 @@ dm_rm_pk_impl <- function(dm, table_name, columns, fail_fk) {
     abort_pk_not_defined()
   }
 
-  pwalk(list(def$fks[i], def$pks[i], def$table[i]),  ~ {
+  pwalk(list(def$fks[i], def$pks[i], def$table[i]), ~ {
     is_match <- !is.na(vec_match(..1$ref_column, ..2$column))
     if (fail_fk && any(is_match)) {
       abort_first_rm_fks(..3, ..1$table[is_match])
@@ -410,7 +410,7 @@ check_pk <- function(table, columns) {
 # Error -------------------------------------------------------------------
 
 abort_pk_not_defined <- function() {
-  abort(error_txt_pk_not_defined(), .subclass = dm_error_full("pk_not_defined"))
+  abort(error_txt_pk_not_defined(), class = dm_error_full("pk_not_defined"))
 }
 
 error_txt_pk_not_defined <- function() {
@@ -418,7 +418,7 @@ error_txt_pk_not_defined <- function() {
 }
 
 abort_key_set_force_false <- function(table) {
-  abort(error_txt_key_set_force_false(table), .subclass = dm_error_full("key_set_force_false"))
+  abort(error_txt_key_set_force_false(table), class = dm_error_full("key_set_force_false"))
 }
 
 error_txt_key_set_force_false <- function(table) {
@@ -426,7 +426,7 @@ error_txt_key_set_force_false <- function(table) {
 }
 
 abort_first_rm_fks <- function(table, fk_tables) {
-  abort(error_txt_first_rm_fks(table, fk_tables), .subclass = dm_error_full("first_rm_fks"))
+  abort(error_txt_first_rm_fks(table, fk_tables), class = dm_error_full("first_rm_fks"))
 }
 
 error_txt_first_rm_fks <- function(table, fk_tables) {
