@@ -56,13 +56,14 @@ db_schema_list.src_dbi <- function(con, include_default = TRUE, ...) {
     paste0(DBI::dbQuoteIdentifier(con, dbname), ".")
   }
   default_if_true <- if_else(include_default, "", " AND NOT s.name = 'dbo'")
-  DBI::dbGetQuery(con, glue::glue("SELECT s.name as schema_name,
-    u.name AS schema_owner
+  # ignore built-in schemas for backward compatibility:
+  # https://docs.microsoft.com/en-us/sql/relational-databases/security/authentication-access/ownership-and-user-schema-separation?view=sql-server-ver15
+  DBI::dbGetQuery(con, glue::glue("SELECT s.name as schema_name
     FROM {dbname_sql}sys.schemas s
-    INNER JOIN {dbname_sql}sys.sysusers u
-    ON u.uid = s.principal_id
-    WHERE u.issqluser = 1
-    AND u.name NOT IN ('sys', 'guest', 'INFORMATION_SCHEMA'){default_if_true}")) %>%
+    WHERE s.name NOT IN ('sys', 'guest', 'INFORMATION_SCHEMA', 'db_accessadmin',
+          'db_backupoperator', 'db_datareader', 'db_datawriter', 'db_ddladmin',
+          'db_denydatareader', 'db_denydatawriter', 'db_owner',
+          'db_securityadmin'){default_if_true}")) %>%
     as_tibble()
 }
 
@@ -262,9 +263,6 @@ sql_schema_table_list_mssql <- function(con, schema = NULL, dbname = NULL) {
     check_param_class(schema, "character")
     check_param_length(schema)
   }
-  if (!is_null(schema) && !db_schema_exists(src$con, schema, dbname)) {
-    abort_no_schema_exists(sql_to_character(src$con, schema), dbname)
-  }
   if (!is_null(dbname)) {
     check_param_class(dbname, "character")
     check_param_length(dbname)
@@ -285,9 +283,6 @@ sql_schema_table_list_postgres <- function(con, schema = NULL) {
     check_param_class(schema, "character")
     check_param_length(schema)
   }
-  if (!is_null(schema) && !db_schema_exists(src$con, schema)) {
-    abort_no_schema_exists(sql_to_character(src$con, schema))
-  }
   enframe(
     get_src_tbl_names(src, schema = sql_to_character(src$con, schema)),
     name = "table_name",
@@ -338,9 +333,6 @@ db_schema_drop <- function(con, schema, force = FALSE, ...) {
     deprecate_soft("0.2.5", 'dm::db_schema_drop(con = "must be a DBI connection, not a dbplyr source,")', )
   }
 
-  if (!db_schema_exists(con, schema, ...)) {
-    abort_no_schema_exists(sql_to_character(con_from_src_or_con(con), schema), ...)
-  }
   UseMethod("db_schema_drop")
 }
 
