@@ -39,13 +39,22 @@ validate_dm <- function(x) {
 
   dm_col_names <- set_names(map(def$data, colnames), table_names)
 
-  fks <- c_list_of(def$fks)
+  fks <-
+    def %>%
+    select(ref_table = table, fks) %>%
+    unnest_list_of_df("fks")
+
   check_fk_child_tables(fks$table, table_names)
 
   fks %>%
     unnest_col("column", character()) %>%
     check_colnames(dm_col_names, "FK")
 
+  fks %>%
+    unnest_col("ref_column", character()) %>%
+    select(table = ref_table, column = ref_column) %>%
+    check_colnames(dm_col_names, "Parent key")
+
   pks <-
     def %>%
     select(table, pks) %>%
