@@ -11,18 +11,7 @@ test_src_duckdb <- function() {
 }
 
 test_src_postgres <- function() {
-  if (Sys.getenv("CI") != "") {
-    con <- DBI::dbConnect(
-      RPostgres::Postgres(),
-      dbname = "test",
-      host = "localhost",
-      port = 5432,
-      user = "postgres",
-      password = "password"
-    )
-  } else {
-    con <- DBI::dbConnect(RPostgres::Postgres())
-  }
+  con <- DBI::dbConnect(RPostgres::Postgres())
   dbplyr::src_dbi(con, auto_disconnect = TRUE)
 }
 
@@ -37,7 +26,7 @@ test_src_mssql <- function() {
       odbc::odbc(),
       "mssql-test",
       uid = "SA",
-      pwd = "Password12",
+      pwd = "YourStrong!Passw0rd",
       port = 1433
     )
   } else {
