@@ -1,3 +1,10 @@
+test_that("data structure", {
+  expect_snapshot({
+    dm_more_complex() %>%
+      dm_paste(options = c("select", "keys"))
+  })
+})
+
 test_that("get_all_filtered_connected() calculates the paths correctly", {
   # Only need to run for local sources
   skip_if_remote_src()
@@ -12,7 +19,8 @@ test_that("get_all_filtered_connected() calculates the paths correctly", {
   expect_not_pred(fc, c("tf_1", "tf_4_2"))
 
   # more complicated graph structure:
-  fc <- dm_more_complex() %>%
+  fc <-
+    dm_more_complex() %>%
     dm_filter(tf_6, TRUE) %>%
     dm_filter(tf_6_2, TRUE) %>%
     get_all_filtered_connected("tf_4")
@@ -20,13 +28,15 @@ test_that("get_all_filtered_connected() calculates the paths correctly", {
   expect_pred_chain(fc, c("tf_6_2", "tf_3", "tf_4"))
 
   # filter in an unconnected component:
-  fc <- dm_more_complex() %>%
+  fc <-
+    dm_more_complex() %>%
     dm_filter(tf_6, TRUE) %>%
     get_all_filtered_connected("a")
   expect_identical(fc$node, "a")
 
 
-  fc <- dm_more_complex() %>%
+  fc <-
+    dm_more_complex() %>%
     dm_filter(tf_5, TRUE) %>%
     get_all_filtered_connected("tf_3")
   expect_pred_chain(fc, c("tf_5", "tf_4", "tf_3"))
@@ -93,32 +103,39 @@ test_that("we get filtered/unfiltered tables with respective funs", {
     filter(tf_1(), a > 4)
   )
 
-  expect_equivalent_tbl_lists(
-    dm_filter(dm_for_filter(), tf_1, a > 3, a < 8) %>% dm_apply_filters() %>% dm_get_tables(),
-    output_1()
-  )
+  expect_snapshot({
+    dm_for_filter() %>%
+      dm_filter(tf_1, a > 3, a < 8) %>%
+      dm_apply_filters() %>%
+      dm_get_tables() %>%
+      map(harmonize_tbl)
+  })
 })
 
 test_that("dm_filter() works as intended for reversed dm", {
-  expect_equivalent_tbl_lists(
-    dm_filter(dm_for_filter_rev(), tf_1, a < 8, a > 3) %>%
+  expect_snapshot({
+    dm_for_filter_rev() %>%
+      dm_filter(tf_1, a < 8, a > 3) %>%
       dm_apply_filters() %>%
-      dm_get_tables(),
-    rev(output_1())
-  )
+      dm_get_tables() %>%
+      map(harmonize_tbl)
+  })
 })
-4
+
 test_that("dm_filter() works as intended for inbetween table", {
-  expect_equivalent_tbl_lists(
-    dm_filter(dm_for_filter(), tf_3, g == "five") %>% dm_apply_filters() %>% dm_get_tables(),
-    output_3()
-  )
+  expect_snapshot({
+    dm_for_filter() %>%
+      dm_filter(tf_3, g == "five") %>%
+      dm_apply_filters() %>%
+      dm_get_tables() %>%
+      map(harmonize_tbl)
+  })
 })
 
 test_that("dm_filter() works without primary keys", {
   expect_silent(
     dm_for_filter() %>%
-      dm_rm_pk(tf_5, rm_referencing_fks = TRUE) %>%
+      dm_rm_pk(tf_5, fail_fk = FALSE) %>%
       dm_filter(tf_5, l == "c") %>%
       collect()
   )
