@@ -14,4 +14,14 @@ test_that("`pack_join()` works", {
   expect_snapshot_error(pack_join(df1, dm_fin$accounts, by = c(col1 = "id")))
   # unless copy = TRUE
   expect_snapshot(pack_join(df1, dm_fin$accounts, by = c(col1 = "id"), copy = TRUE))
+
+  # when we have conflicting columns, the column in x is overwritten silently
+  # consistent with dplyr::nest_join
+  df4 <- tibble(df5 = integer())
+  df5 <- tibble(col = integer())
+  expect_snapshot(pack_join(df4, df5, by = c(df5 = "col")))
+
+  # No conflict occurs when packing `y` before the join
+  df6 <- tibble(df6 = integer())
+  expect_snapshot(pack_join(df5, df6, by = c(col = "df6")))
 })
